"""This package contains example applications included with Lino.

See also :doc:`/tutorials/hello` which explains how to try them out.

Examples with their own documentation entry:

- :mod:`lino.projects.belref` ---
  See :ref:`belref`
- :mod:`lino.projects.presto`
  See :ref:`presto`
- :mod:`lino.projects.polly`
  See :ref:`polly`

Poorly documented examples at different development states:

- :mod:`lino.projects.min1`
- :mod:`lino.projects.min2`
- :mod:`lino.projects.cms` ---
  :doc:`/tickets/66`
- :mod:`lino.projects.crl`
- :mod:`lino.projects.events`
  See :blogref:`20140203`
- :mod:`lino.projects.homeworkschool`
- :mod:`lino.projects.igen`
- :mod:`lino.projects.start`

Examples covered by a tutorial:

- :mod:`lino.projects.babel_tutorial` ---
  See :ref:`mldbc_tutorial`

- :mod:`lino.projects.i18n` ---
  See :ref:`lino.tested.i18n`

Technical

- :mod:`lino.projects.docs` -- A fictive application needed to satisfy
  autodoc when generating the API documentation for :mod:`lino`.

- :mod:`lino.projects.std` --
  The parent of every Lino application.

"""

